@@ -44,4 +44,13 @@ def printStatus(repo, count=True):
 			print '[{0}] {1} => {2}'.format(repo['name'], repo['remote'], repo['local'])
 	else:
 		terminal.clear_line()
-		terminal.progress_bar(project.Project.projectCount, project.Project.currentProj, 30, repo['name'])
\ No newline at end of file
+		terminal.progress_bar(project.Project.projectCount, project.Project.currentProj, 30, repo['name'])
+
+def checkRemote(repo):
+	command = ''
+	if isGitCheckout(repo):
+		command = 'git remote -v'
+	else:
+		command = 'svn info '
+	result = executeCommand(command, cwd=repo['local'])
+	return (repo['remote'] in result['stdout']) or (result['returncode'] != 0)
